@@ -27,7 +27,7 @@ from typing import (
 from kiwi.path import Path
 from kiwi.utils.temporary import Temporary
 from kiwi.command import Command
-from kiwi.exceptions import KiwiUmountBusyError
+from kiwi.exceptions import KiwiCommandError, KiwiUmountBusyError
 
 log = logging.getLogger('kiwi')
 
@@ -36,10 +36,11 @@ class MountManager:
     """
     **Implements methods for mounting, umounting and mount checking**
 
-    If a MountManager instance is used to mount a device the caller
-    must care for the time when umount needs to be called. The class
-    does not automatically release the mounted device, which is
-    intentional
+    The caller is responsible for unmounting the device if the MountManager is
+    used as is.
+
+    The class also supports to be used as a context manager, where the device is
+    unmounted once the context manager's with block is left
 
     * :param string device: device node name
     * :param string mountpoint: mountpoint directory name
@@ -60,6 +61,12 @@ class MountManager:
             Path.create(mountpoint)
             self.mountpoint = mountpoint
 
+    def __enter__(self) -> "MountManager":
+        return self
+
+    def __exit__(self, exc_type, exc_value, traceback) -> None:
+        self.umount()
+
     def get_attributes(self) -> Dict[str, str]:
         """
         Return attributes dict for this mount manager
@@ -143,17 +150,24 @@ class MountManager:
         """
         if self.is_mounted():
             umounted_successfully = False
-            for busy in range(0, 10):
+            for busy in range(0, 5):
                 try:
                     Command.run(['umount', self.mountpoint])
                     umounted_successfully = True
                     break
-                except Exception:
+                except KiwiCommandError as err:
                     log.warning(
-                        '%d umount of %s failed, try again in 1sec',
-                        busy, self.mountpoint
+                        f'{busy} umount of {self.mountpoint} failed with: {err}'
                     )
                     time.sleep(1)
+            if not umounted_successfully:
+                try:
+                    Command.run(['umount', '--lazy', self.mountpoint])
+                    umounted_successfully = True
+                except KiwiCommandError as err:
+                    log.error(
+                        f'umount of {self.mountpoint} failed with: {err}'
+                    )
             if not umounted_successfully:
                 if raise_on_busy:
                     lsof = Path.which('lsof', access_mode=os.X_OK)
@@ -207,7 +221,4 @@ class MountManager:
             command=['mountpoint', '-q', self.mountpoint],
             raise_on_error=False
         )
-        if mountpoint_call.returncode == 0:
-            return True
-        else:
-            return False
+        return mountpoint_call.returncode == 0
