@@ -15,26 +15,35 @@
 # You should have received a copy of the GNU General Public License
 # along with kiwi.  If not, see <http://www.gnu.org/licenses/>
 #
-# project
-from kiwi.oci_tools.umoci import OCIUmoci
-from kiwi.oci_tools.buildah import OCIBuildah
-from kiwi.runtime_config import RuntimeConfig
+from abc import (
+    ABCMeta,
+    abstractmethod
+)
+from kiwi.oci_tools.base import OCIBase
 
+# project
+from kiwi.runtime_config import RuntimeConfig
 from kiwi.exceptions import (
     KiwiOCIArchiveToolError
 )
 
 
-class OCI:
+class OCI(metaclass=ABCMeta):
     """
     **OCI Factory**
     """
-    def __new__(self):
-        runtime_config = RuntimeConfig()
-        tool_name = runtime_config.get_oci_archive_tool()
-        if tool_name == 'umoci':
+    @abstractmethod
+    def __init__(self) -> None:
+        return None  # pragma: no cover
+
+    @staticmethod
+    def new() -> OCIBase:
+        tool_name = RuntimeConfig().get_oci_archive_tool()
+        if tool_name == "umoci":
+            from kiwi.oci_tools.umoci import OCIUmoci
             return OCIUmoci()
-        elif tool_name == 'buildah':
+        elif tool_name == "buildah":
+            from kiwi.oci_tools.buildah import OCIBuildah
             return OCIBuildah()
         else:
             raise KiwiOCIArchiveToolError(
