@@ -20,7 +20,7 @@ import simplejson
 import pickle
 import os
 from typing import (
-    Dict, NamedTuple, TypeVar, Any
+    Dict, NamedTuple, TypeVar, Any, Optional
 )
 
 # project
@@ -164,7 +164,7 @@ class Result:
                     )
         except Exception as e:
             raise KiwiResultError(
-                'Failed to pickle dump results: %s' % format(e)
+                f'Failed to pickle dump results: {format(e)}'
             )
 
     @staticmethod
@@ -179,18 +179,18 @@ class Result:
         """
         if not os.path.exists(filename):
             raise KiwiResultError(
-                'No result information %s found' % filename
+                f'No result information {filename} found'
             )
         try:
             with open(filename, 'rb') as result:
                 return pickle.load(result)
         except Exception as e:
             raise KiwiResultError(
-                'Failed to pickle load results: %s' % type(e).__name__
+                f'Failed to pickle load results: {type(e).__name__}'
             )
 
     @staticmethod
-    def verify_image_size(size_limit: int, filename: str) -> None:
+    def verify_image_size(size_limit: Optional[int], filename: str) -> None:
         """
         Verifies the given image file does not exceed the size limit.
         Throws an exception if the limit is exceeded. If the size limit
