@@ -16,10 +16,10 @@
 # along with kiwi.  If not, see <http://www.gnu.org/licenses/>
 #
 import os
+import errno
 import logging
 from stat import ST_MODE
 from typing import List
-import xattr
 
 # project
 from kiwi.command import Command
@@ -89,11 +89,11 @@ class DataSync:
             rsync_options = options
         if not self.target_supports_extended_attributes():
             warn_me = False
-            if '-X' in rsync_options:
-                rsync_options.remove('-X')
+            if '--xattrs' in rsync_options:
+                rsync_options.remove('--xattrs')
                 warn_me = True
-            if '-A' in rsync_options:
-                rsync_options.remove('-A')
+            if '--acls' in rsync_options:
+                rsync_options.remove('--acls')
                 warn_me = True
             if warn_me:
                 log.warning(
@@ -134,9 +134,11 @@ class DataSync:
         :rtype: bool
         """
         try:
-            xattr.getxattr(self.target_dir, 'user.mime_type')
-        except Exception as e:
-            if format(e).startswith('[Errno 95]'):
-                # libc interface [Errno 95] Operation not supported:
+            os.getxattr(self.target_dir, 'user.mime_type')
+        except OSError as e:
+            log.debug(
+                f'Check for extended attributes on {self.target_dir} said: {e}'
+            )
+            if e.errno == errno.ENOTSUP:
                 return False
         return True
