@@ -15,7 +15,7 @@
 # You should have received a copy of the GNU General Public License
 # along with kiwi.  If not, see <http://www.gnu.org/licenses/>
 #
-from typing import IO
+from typing import IO, NamedTuple
 
 from tempfile import (
     NamedTemporaryFile,
@@ -26,6 +26,10 @@ from tempfile import (
 import kiwi.defaults as defaults
 
 
+class TmpT(NamedTuple):
+    name: str
+
+
 class Temporary:
     """
     **Provides namespace to handle temporary files and directories**
@@ -45,3 +49,6 @@ class Temporary:
         return TemporaryDirectory(
             dir=self.path, prefix=self.prefix
         )
+
+    def unmanaged_file(self) -> TmpT:
+        return TmpT(name=f'{self.path}/{self.prefix}')
