@@ -1,4 +1,4 @@
-from mock import (
+from unittest.mock import (
     Mock, patch
 )
 from pytest import raises
