@@ -24,14 +24,26 @@ class TestFileSystemBtrfs:
 
     @patch('kiwi.filesystem.btrfs.Command.run')
     def test_create_on_device(self, mock_command):
-        self.btrfs.create_on_device('label', 100, uuid='uuid')
-        call = mock_command.call_args_list[0]
-        assert mock_command.call_args_list[0] == call(
-            [
-                'mkfs.btrfs', '-L', 'label', '-U', 'uuid',
-                '--byte-count', '102400', '/dev/foo'
-            ]
-        )
+        with patch.dict('os.environ', {'SOURCE_DATE_EPOCH': '0'}):
+            self.btrfs.create_on_device('label', 100, uuid='uuid')
+            call = mock_command.call_args_list[0]
+            assert mock_command.call_args_list[0] == call(
+                [
+                    'mkfs.btrfs', '-L', 'label', '-U', 'uuid',
+                    '--byte-count', '102400', '/dev/foo'
+                ]
+            )
+            mock_command.reset_mock()
+            self.btrfs.create_on_device('label', 100)
+            assert mock_command.call_args_list[0] == call(
+                [
+                    'mkfs.btrfs',
+                    '-L', 'label',
+                    '-U', '2453562e-7073-2098-d091-fd7a04dc5434',
+                    '--byte-count', '102400',
+                    '/dev/foo'
+                ]
+            )
 
     @patch('kiwi.filesystem.btrfs.Command.run')
     def test_set_uuid(self, mock_command):
