@@ -26,14 +26,26 @@ class TestFileSystemXfs:
 
     @patch('kiwi.filesystem.xfs.Command.run')
     def test_create_on_device(self, mock_command):
-        self.xfs.create_on_device('label', 100, uuid='uuid')
-        call = mock_command.call_args_list[0]
-        assert mock_command.call_args_list[0] == call(
-            [
-                'mkfs.xfs', '-f', '-L', 'label',
-                '-m', 'uuid=uuid', '-d', 'size=100k', '/dev/foo'
-            ]
-        )
+        with patch.dict('os.environ', {'SOURCE_DATE_EPOCH': '0'}):
+            self.xfs.create_on_device('label', 100, uuid='uuid')
+            call = mock_command.call_args_list[0]
+            assert mock_command.call_args_list[0] == call(
+                [
+                    'mkfs.xfs', '-f', '-L', 'label',
+                    '-m', 'uuid=uuid', '-d', 'size=100k', '/dev/foo'
+                ]
+            )
+            mock_command.reset_mock()
+            self.xfs.create_on_device('label', 100)
+            assert mock_command.call_args_list[0] == call(
+                [
+                    'mkfs.xfs', '-f',
+                    '-L', 'label',
+                    '-m', 'uuid=2453562e-7073-2098-d091-fd7a04dc5434',
+                    '-d', 'size=100k',
+                    '/dev/foo'
+                ]
+            )
 
     @patch('kiwi.filesystem.xfs.Command.run')
     def test_set_uuid(self, mock_command):
