@@ -1,6 +1,6 @@
 from pytest import raises
-from mock import patch
-import mock
+from unittest.mock import patch
+import unittest.mock as mock
 
 from kiwi.iso_tools import IsoTools
 from kiwi.exceptions import KiwiIsoToolError
@@ -11,6 +11,9 @@ class TestIsoTools:
         self.runtime_config = mock.Mock()
         self.runtime_config.get_iso_tool_category = mock.Mock()
 
+    def setup_method(self, cls):
+        self.setup()
+
     @patch('kiwi.iso_tools.xorriso.IsoToolsXorrIso')
     @patch('kiwi.iso_tools.RuntimeConfig')
     def test_iso_tools_xorriso(
