@@ -1,4 +1,4 @@
-from mock import patch
+from unittest.mock import patch
 
 from kiwi.markup import Markup
 
@@ -6,14 +6,14 @@ from kiwi.exceptions import KiwiAnyMarkupPluginError
 
 
 class TestMarkup:
-    @patch('kiwi.markup.MarkupAny')
+    @patch('kiwi.markup.any.MarkupAny')
     def test_MarkupAny(self, mock_MarkupAny):
-        Markup('description')
+        Markup.new('description')
         mock_MarkupAny.assert_called_once_with('description')
 
-    @patch('kiwi.markup.MarkupXML')
-    @patch('kiwi.markup.MarkupAny')
+    @patch('kiwi.markup.xml.MarkupXML')
+    @patch('kiwi.markup.any.MarkupAny')
     def test_MarkupXML(self, mock_MarkupAny, mock_MarkupXML):
         mock_MarkupAny.side_effect = KiwiAnyMarkupPluginError('load-error')
-        Markup('description')
+        Markup.new('description')
         mock_MarkupXML.assert_called_once_with('description')
