@@ -1,11 +1,12 @@
 import logging
+from typing import NoReturn
 from pytest import (
     fixture, raises
 )
-from mock import (
+from unittest.mock import (
     patch, call, Mock
 )
-from kiwi.exceptions import KiwiUmountBusyError
+from kiwi.exceptions import KiwiCommandError, KiwiUmountBusyError
 from kiwi.mount_manager import MountManager
 
 
@@ -78,6 +79,16 @@ class TestMountManager:
             ['mount', '-o', 'options', '/dev/some-device', '/some/mountpoint']
         )
 
+    @patch('kiwi.mount_manager.Command.run')
+    @patch('kiwi.mount_manager.MountManager.is_mounted')
+    def test_context_manager(self, mock_mounted, mock_command):
+        mock_mounted.return_value = True
+        with self.mount_manager:
+            pass
+        mock_command.assert_called_once_with(
+            ['umount', '/some/mountpoint']
+        )
+
     @patch('kiwi.mount_manager.Command.run')
     @patch('kiwi.mount_manager.MountManager.is_mounted')
     def test_umount_lazy(self, mock_mounted, mock_command):
@@ -87,13 +98,43 @@ class TestMountManager:
             ['umount', '-l', '/some/mountpoint']
         )
 
+    @patch('kiwi.mount_manager.Command.run')
+    @patch('kiwi.mount_manager.MountManager.is_mounted')
+    @patch('time.sleep')
+    def test_umount_with_errors_but_lazy(
+        self, mock_sleep, mock_mounted, mock_command
+    ):
+        command_errors = [
+            True, False, False, False, False, False
+        ]
+
+        def _cmd_err(args) -> NoReturn:
+            if not command_errors.pop():
+                raise KiwiCommandError('error')
+
+        mock_command.side_effect = _cmd_err
+        mock_mounted.return_value = True
+        with self._caplog.at_level(logging.WARNING):
+            assert self.mount_manager.umount() is True
+        assert mock_command.call_args_list == [
+            call(['umount', '/some/mountpoint']),  # 1
+            call(['umount', '/some/mountpoint']),  # 2
+            call(['umount', '/some/mountpoint']),  # 3
+            call(['umount', '/some/mountpoint']),  # 4
+            call(['umount', '/some/mountpoint']),  # 5
+            call(['umount', '--lazy', '/some/mountpoint']),  # lazy
+        ]
+
     @patch('kiwi.mount_manager.Command.run')
     @patch('kiwi.mount_manager.MountManager.is_mounted')
     @patch('time.sleep')
     def test_umount_with_errors(
         self, mock_sleep, mock_mounted, mock_command
     ):
-        mock_command.side_effect = Exception
+        def _cmd_err(args) -> NoReturn:
+            raise KiwiCommandError('error')
+
+        mock_command.side_effect = _cmd_err
         mock_mounted.return_value = True
         with self._caplog.at_level(logging.WARNING):
             assert self.mount_manager.umount(raise_on_busy=False) is False
@@ -103,11 +144,7 @@ class TestMountManager:
             call(['umount', '/some/mountpoint']),  # 3
             call(['umount', '/some/mountpoint']),  # 4
             call(['umount', '/some/mountpoint']),  # 5
-            call(['umount', '/some/mountpoint']),  # 6
-            call(['umount', '/some/mountpoint']),  # 7
-            call(['umount', '/some/mountpoint']),  # 8
-            call(['umount', '/some/mountpoint']),  # 9
-            call(['umount', '/some/mountpoint'])   # 10
+            call(['umount', '--lazy', '/some/mountpoint']),  # lazy
         ]
 
     @patch('kiwi.mount_manager.Command.run')
@@ -119,7 +156,7 @@ class TestMountManager:
     ):
         def command_call(args):
             if 'umount' in args:
-                raise Exception
+                raise KiwiCommandError('error')
 
         mock_Path_which.return_value = None
         mock_command.side_effect = command_call
@@ -136,7 +173,7 @@ class TestMountManager:
     ):
         def command_call(args, raise_on_error=None):
             if 'umount' in args:
-                raise Exception
+                raise KiwiCommandError('error')
             else:
                 call_return = Mock()
                 call_return.output = 'HEADLINE\ndata'
