@@ -1,5 +1,5 @@
 import logging
-from mock import (
+from unittest.mock import (
     patch, call, mock_open, Mock
 )
 from pytest import (
