@@ -53,9 +53,10 @@ class TestLuksDevice:
         assert self.luks.get_device() is None
 
     @patch('kiwi.storage.luks_device.Command.run')
+    @patch('kiwi.storage.luks_device.Checksum')
     @patch('os.chmod')
     def test_create_crypto_luks_empty_passphrase(
-        self, mock_os_chmod, mock_command
+        self, mock_os_chmod, mock_Checksum, mock_command
     ):
         with patch('builtins.open', create=True):
             self.luks.create_crypto_luks(
@@ -85,6 +86,14 @@ class TestLuksDevice:
                         'luksAddKey', '/dev/some-device', 'root/some-keyfile'
                     ]
                 ),
+                call(
+                    [
+                        'cryptsetup', '--key-file', '/dev/zero',
+                        '--keyfile-size', '32',
+                        'luksHeaderBackup', '/dev/some-device',
+                        '--header-backup-file', 'root/root/.luks.header'
+                    ]
+                ),
                 call(
                     [
                         'cryptsetup', '--key-file', '/dev/zero',
@@ -93,14 +102,70 @@ class TestLuksDevice:
                     ]
                 )
             ]
+            mock_Checksum.return_value.sha256.assert_called_once_with()
             self.luks.luks_device = None
 
     @patch('kiwi.storage.luks_device.LuksDevice')
     @patch('kiwi.storage.luks_device.Command.run')
     @patch('kiwi.storage.luks_device.Temporary.new_file')
+    @patch('kiwi.storage.luks_device.Checksum')
+    @patch('os.chmod')
+    def test_create_crypto_luks_random_passphrase(
+        self, mock_os_chmod, mock_Checksum, mock_tmpfile,
+        mock_command, mock_LuksDevice
+    ):
+        tmpfile = Mock()
+        tmpfile.name = 'tmpfile'
+        mock_tmpfile.return_value = tmpfile
+        with patch('builtins.open', create=True):
+            self.luks.create_crypto_luks(
+                passphrase='random', osname='sle12',
+                keyfile='some-keyfile', root_dir='root'
+            )
+            assert mock_command.call_args_list == [
+                call(
+                    [
+                        'dd', 'if=/dev/urandom', 'bs=1M', 'count=1',
+                        'of=/dev/some-device'
+                    ]
+                ),
+                call(
+                    [
+                        'cryptsetup', '-q', '--key-file', 'root/some-keyfile',
+                        '--cipher', 'aes-xts-plain64',
+                        '--key-size', '256', '--hash', 'sha1',
+                        'luksFormat', '/dev/some-device'
+                    ]
+                ),
+                call(
+                    [
+                        'cryptsetup', '--key-file', 'root/some-keyfile',
+                        'luksHeaderBackup', '/dev/some-device',
+                        '--header-backup-file', 'root/root/.luks.header'
+                    ]
+                ),
+                call(
+                    [
+                        'cryptsetup', '--key-file', 'root/some-keyfile', 'luksOpen',
+                        '/dev/some-device', 'luksRoot'
+                    ]
+                )
+            ]
+            mock_Checksum.return_value.sha256.assert_called_once_with()
+            mock_LuksDevice.create_random_keyfile.assert_called_once_with(
+                'root/some-keyfile'
+            )
+            assert self.luks.luks_keyfile == 'some-keyfile'
+            self.luks.luks_device = ''
+
+    @patch('kiwi.storage.luks_device.LuksDevice')
+    @patch('kiwi.storage.luks_device.Command.run')
+    @patch('kiwi.storage.luks_device.Temporary.new_file')
+    @patch('kiwi.storage.luks_device.Checksum')
     @patch('os.chmod')
     def test_create_crypto_luks(
-        self, mock_os_chmod, mock_tmpfile, mock_command, mock_LuksDevice
+        self, mock_os_chmod, mock_Checksum, mock_tmpfile,
+        mock_command, mock_LuksDevice
     ):
         tmpfile = Mock()
         tmpfile.name = 'tmpfile'
@@ -131,6 +196,13 @@ class TestLuksDevice:
                         '/dev/some-device', 'root/some-keyfile'
                     ]
                 ),
+                call(
+                    [
+                        'cryptsetup', '--key-file', 'tmpfile',
+                        'luksHeaderBackup', '/dev/some-device',
+                        '--header-backup-file', 'root/root/.luks.header'
+                    ]
+                ),
                 call(
                     [
                         'cryptsetup', '--key-file', 'tmpfile', 'luksOpen',
@@ -138,6 +210,7 @@ class TestLuksDevice:
                     ]
                 )
             ]
+            mock_Checksum.return_value.sha256.assert_called_once_with()
             mock_LuksDevice.create_random_keyfile.assert_called_once_with(
                 'root/some-keyfile'
             )
@@ -174,7 +247,7 @@ class TestLuksDevice:
             mock_open.return_value = MagicMock(spec=io.IOBase)
             file_handle = mock_open.return_value.__enter__.return_value
             LuksDevice.create_random_keyfile('some-file')
-            file_handle.write.assert_called_once_with(secret)
+            file_handle.write.assert_called_once_with('736563726574')
             mock_os_chmod.assert_called_once_with('some-file', 0o600)
 
     def test_is_loop(self):
