@@ -1,5 +1,5 @@
 from textwrap import dedent
-from mock import (
+from unittest.mock import (
     patch, Mock, call, mock_open
 )
 
