@@ -1,6 +1,6 @@
-from mock import patch
+from unittest.mock import patch
 
-from mock import Mock
+from unittest.mock import Mock
 import kiwi
 
 from kiwi.defaults import Defaults
@@ -28,6 +28,9 @@ class TestDiskFormatVdi:
             self.xml_state, 'root_dir', 'target_dir'
         )
 
+    def setup_method(self, cls):
+        self.setup()
+
     def test_post_init(self):
         self.disk_format.post_init({'option': 'value'})
         assert self.disk_format.options == ['-o', 'option=value']
