@@ -1,7 +1,7 @@
 import logging
 import os
 import sys
-from mock import (
+from unittest.mock import (
     Mock, patch
 )
 from pytest import (
@@ -41,13 +41,9 @@ class TestImageResizeTask:
         self.firmware.get_partition_table_type = Mock(
             return_value='gpt'
         )
-        self.loop_provider = Mock()
         kiwi.tasks.image_resize.FirmWare = Mock(
             return_value=self.firmware
         )
-        kiwi.tasks.image_resize.LoopDevice = Mock(
-            return_value=self.loop_provider
-        )
 
         self.task = ImageResizeTask()
 
@@ -77,7 +73,7 @@ class TestImageResizeTask:
     def test_process_no_raw_disk_found(self, mock_DiskFormat):
         image_format = Mock()
         image_format.has_raw_disk.return_value = False
-        mock_DiskFormat.return_value = image_format
+        mock_DiskFormat.return_value.__enter__.return_value = image_format
         self._init_command_args()
         self.task.command_args['resize'] = True
         with raises(KiwiImageResizeError):
@@ -87,87 +83,103 @@ class TestImageResizeTask:
     def test_process_unsupported_size_format(self, mock_DiskFormat):
         image_format = Mock()
         image_format.has_raw_disk.return_value = True
-        mock_DiskFormat.return_value = image_format
+        mock_DiskFormat.return_value.__enter__.return_value = image_format
         self._init_command_args()
         self.task.command_args['--size'] = '20x'
         self.task.command_args['resize'] = True
         with raises(KiwiSizeError):
             self.task.process()
 
+    @patch('kiwi.tasks.image_resize.LoopDevice')
     @patch('kiwi.tasks.image_resize.DiskFormat.new')
     @patch('kiwi.tasks.image_resize.Partitioner.new')
-    def test_process_image_resize_gb(self, mock_Partitioner, mock_DiskFormat):
+    def test_process_image_resize_gb(
+        self, mock_Partitioner, mock_DiskFormat, mock_LoopDevice
+    ):
+        loop_provider = Mock()
+        mock_LoopDevice.return_value.__enter__.return_value = loop_provider
         partitioner = Mock()
         mock_Partitioner.return_value = partitioner
         image_format = Mock()
         image_format.resize_raw_disk.return_value = True
-        mock_DiskFormat.return_value = image_format
+        mock_DiskFormat.return_value.__enter__.return_value = image_format
         self._init_command_args()
         self.task.command_args['resize'] = True
         self.task.process()
-        self.loop_provider.create.assert_called_once_with(overwrite=False)
+        loop_provider.create.assert_called_once_with(overwrite=False)
         partitioner.resize_table.assert_called_once_with()
         image_format.resize_raw_disk.assert_called_once_with(
             42 * 1024 * 1024 * 1024
         )
         image_format.create_image_format.assert_called_once_with()
 
+    @patch('kiwi.tasks.image_resize.LoopDevice')
     @patch('kiwi.tasks.image_resize.DiskFormat.new')
     @patch('kiwi.tasks.image_resize.Partitioner.new')
-    def test_process_image_resize_mb(self, mock_Partitioner, mock_DiskFormat):
+    def test_process_image_resize_mb(
+        self, mock_Partitioner, mock_DiskFormat, mock_LoopDevice
+    ):
+        loop_provider = Mock()
+        mock_LoopDevice.return_value.__enter__.return_value = loop_provider
         partitioner = Mock()
         mock_Partitioner.return_value = partitioner
         image_format = Mock()
         image_format.resize_raw_disk.return_value = True
-        mock_DiskFormat.return_value = image_format
+        mock_DiskFormat.return_value.__enter__.return_value = image_format
         self._init_command_args()
         self.task.command_args['resize'] = True
         self.task.command_args['--size'] = '42m'
         self.task.process()
-        self.loop_provider.create.assert_called_once_with(overwrite=False)
+        loop_provider.create.assert_called_once_with(overwrite=False)
         partitioner.resize_table.assert_called_once_with()
         image_format.resize_raw_disk.assert_called_once_with(
             42 * 1024 * 1024
         )
         image_format.create_image_format.assert_called_once_with()
 
+    @patch('kiwi.tasks.image_resize.LoopDevice')
     @patch('kiwi.tasks.image_resize.DiskFormat.new')
     @patch('kiwi.tasks.image_resize.Partitioner.new')
     def test_process_image_resize_bytes(
-        self, mock_Partitioner, mock_DiskFormat
+        self, mock_Partitioner, mock_DiskFormat, mock_LoopDevice
     ):
+        loop_provider = Mock()
+        mock_LoopDevice.return_value.__enter__.return_value = loop_provider
         partitioner = Mock()
         mock_Partitioner.return_value = partitioner
         image_format = Mock()
         image_format.resize_raw_disk.return_value = True
-        mock_DiskFormat.return_value = image_format
+        mock_DiskFormat.return_value.__enter__.return_value = image_format
         self._init_command_args()
         self.task.command_args['resize'] = True
         self.task.command_args['--size'] = '42'
         self.task.process()
-        self.loop_provider.create.assert_called_once_with(overwrite=False)
+        loop_provider.create.assert_called_once_with(overwrite=False)
         partitioner.resize_table.assert_called_once_with()
         image_format.resize_raw_disk.assert_called_once_with(
             42
         )
         image_format.create_image_format.assert_called_once_with()
 
+    @patch('kiwi.tasks.image_resize.LoopDevice')
     @patch('kiwi.tasks.image_resize.DiskFormat.new')
     @patch('kiwi.tasks.image_resize.Partitioner.new')
     def test_process_image_resize_not_needed(
-        self, mock_Partitioner, mock_DiskFormat
+        self, mock_Partitioner, mock_DiskFormat, mock_LoopDevice
     ):
+        loop_provider = Mock()
+        mock_LoopDevice.return_value.__enter__.return_value = loop_provider
         partitioner = Mock()
         mock_Partitioner.return_value = partitioner
         image_format = Mock()
         image_format.resize_raw_disk.return_value = False
-        mock_DiskFormat.return_value = image_format
+        mock_DiskFormat.return_value.__enter__.return_value = image_format
         self._init_command_args()
         self.task.command_args['resize'] = True
         self.task.command_args['--size'] = '42'
         with self._caplog.at_level(logging.INFO):
             self.task.process()
-            self.loop_provider.create.assert_called_once_with(overwrite=False)
+            loop_provider.create.assert_called_once_with(overwrite=False)
             partitioner.resize_table.assert_called_once_with()
             image_format.resize_raw_disk.assert_called_once_with(
                 42
