@@ -156,9 +156,6 @@ class TestSystemBuildTask:
         self.runtime_checker.\
             check_dracut_module_for_oem_install_in_package_list.\
             assert_called_once_with()
-        self.runtime_checker.\
-            check_efi_mode_for_disk_overlay_correctly_setup.\
-            assert_called_once_with()
         system_prepare.setup_repositories.assert_called_once_with(
             False, ['some_key', 'some_other_key'], None
         )
@@ -191,6 +188,7 @@ class TestSystemBuildTask:
         system_prepare.pinch_system.assert_has_calls(
             [call(force=False), call(force=True)]
         )
+        self.setup.create_system_files.assert_called_once_with()
         assert system_prepare.clean_package_manager_leftovers.called
         self.setup.call_image_script.assert_called_once_with()
         self.builder.create.assert_called_once_with()
@@ -341,14 +339,14 @@ class TestSystemBuildTask:
         self.task.process()
         mock_set_repo.assert_called_once_with(
             'http://example.com', 'yast2', 'alias',
-            None, None, None, [], None, None, None
+            None, None, None, [], None, None, None, None
         )
         self.task.command_args['--set-repo-credentials'] = 'user:pass'
         mock_set_repo.reset_mock()
         self.task.process()
         mock_set_repo.assert_called_once_with(
             'http://user:pass@example.com', 'yast2', 'alias',
-            None, None, None, [], None, None, None
+            None, None, None, [], None, None, None, None
         )
         self.task.command_args['--set-repo-credentials'] = '../data/credentials'
         mock_os_path_is_file.return_value = True
@@ -356,7 +354,7 @@ class TestSystemBuildTask:
         self.task.process()
         mock_set_repo.assert_called_once_with(
             'http://user:pass@example.com', 'yast2', 'alias',
-            None, None, None, [], None, None, None
+            None, None, None, [], None, None, None, None
         )
         mock_os_unlink.assert_called_once_with('../data/credentials')
 
@@ -376,15 +374,15 @@ class TestSystemBuildTask:
         assert mock_add_repo.call_args_list == [
             call(
                 'http://example1.com', 'yast2', 'alias', '99',
-                False, True, [], None, None, None
+                False, True, [], None, None, None, None
             ),
             call(
                 'http://example2.com', 'yast2', 'alias', '99',
-                False, True, [], None, None, None
+                False, True, [], None, None, None, None
             ),
             call(
                 'http://example3.com', 'yast2', 'alias', '99',
-                False, True, [], None, None, None
+                False, True, [], None, None, None, None
             )
         ]
         self.task.command_args['--add-repo-credentials'] = [
@@ -396,15 +394,15 @@ class TestSystemBuildTask:
         assert mock_add_repo.call_args_list == [
             call(
                 'http://user1:pass1@example1.com', 'yast2', 'alias', '99',
-                False, True, [], None, None, None
+                False, True, [], None, None, None, None
             ),
             call(
                 'http://user2:pass2@example2.com', 'yast2', 'alias', '99',
-                False, True, [], None, None, None
+                False, True, [], None, None, None, None
             ),
             call(
                 'http://example3.com', 'yast2', 'alias', '99',
-                False, True, [], None, None, None
+                False, True, [], None, None, None, None
             )
         ]
 
