@@ -142,9 +142,6 @@ class TestSystemPrepareTask:
         self.runtime_checker.\
             check_dracut_module_for_oem_install_in_package_list.\
             assert_called_once_with()
-        self.runtime_checker.\
-            check_efi_mode_for_disk_overlay_correctly_setup.\
-            assert_called_once_with()
         system_prepare.setup_repositories.assert_called_once_with(
             True, ['some_key', 'some_other_key'], None
         )
@@ -178,6 +175,7 @@ class TestSystemPrepareTask:
         system_prepare.pinch_system.assert_has_calls(
             [call(force=False), call(force=True)]
         )
+        self.setup.create_system_files.assert_called_once_with()
         assert system_prepare.clean_package_manager_leftovers.called
 
     @patch('kiwi.xml_state.XMLState.get_repositories_signing_keys')
@@ -308,18 +306,23 @@ class TestSystemPrepareTask:
     ):
         mock_os_path_is_file.return_value = False
         self._init_command_args()
-        self.task.command_args['--set-repo'] = 'http://example.com,yast2,alias'
+        self.task.command_args['--set-repo'] = \
+            'http://example.com,yast2,alias,prio,imageinclude,' + \
+            'package_gpgcheck,{file:///key.asc},components,dist,' + \
+            'repo_gpgcheck,repo_sourcetype'
         self.task.process()
         mock_set_repo.assert_called_once_with(
             'http://example.com', 'yast2', 'alias',
-            None, None, None, [], None, None, None
+            'prio', 'imageinclude', 'package_gpgcheck', ['file:///key.asc'],
+            'components', 'dist', 'repo_gpgcheck', 'repo_sourcetype'
         )
         self.task.command_args['--set-repo-credentials'] = 'user:pass'
         mock_set_repo.reset_mock()
         self.task.process()
         mock_set_repo.assert_called_once_with(
             'http://user:pass@example.com', 'yast2', 'alias',
-            None, None, None, [], None, None, None
+            'prio', 'imageinclude', 'package_gpgcheck', ['file:///key.asc'],
+            'components', 'dist', 'repo_gpgcheck', 'repo_sourcetype'
         )
         self.task.command_args['--set-repo-credentials'] = '../data/credentials'
         mock_os_path_is_file.return_value = True
@@ -327,7 +330,8 @@ class TestSystemPrepareTask:
         self.task.process()
         mock_set_repo.assert_called_once_with(
             'http://user:pass@example.com', 'yast2', 'alias',
-            None, None, None, [], None, None, None
+            'prio', 'imageinclude', 'package_gpgcheck', ['file:///key.asc'],
+            'components', 'dist', 'repo_gpgcheck', 'repo_sourcetype'
         )
         mock_os_unlink.assert_called_once_with('../data/credentials')
 
@@ -346,15 +350,15 @@ class TestSystemPrepareTask:
         assert mock_add_repo.call_args_list == [
             call(
                 'http://example1.com', 'yast2', 'alias', '99',
-                True, None, [], None, None, None
+                True, None, [], None, None, None, None
             ),
             call(
                 'http://example2.com', 'yast2', 'alias', '99',
-                False, True, [], None, None, None
+                False, True, [], None, None, None, None
             ),
             call(
                 'http://example3.com', 'yast2', 'alias', '99',
-                False, True, [], None, None, None
+                False, True, [], None, None, None, None
             )
         ]
         self.task.command_args['--add-repo-credentials'] = [
@@ -366,15 +370,15 @@ class TestSystemPrepareTask:
         assert mock_add_repo.call_args_list == [
             call(
                 'http://user1:pass1@example1.com', 'yast2', 'alias', '99',
-                True, None, [], None, None, None
+                True, None, [], None, None, None, None
             ),
             call(
                 'http://user2:pass2@example2.com', 'yast2', 'alias', '99',
-                False, True, [], None, None, None
+                False, True, [], None, None, None, None
             ),
             call(
                 'http://example3.com', 'yast2', 'alias', '99',
-                False, True, [], None, None, None
+                False, True, [], None, None, None, None
             )
         ]
 
