@@ -1,4 +1,4 @@
-from mock import (
+from unittest.mock import (
     call, mock_open, patch
 )
 
