@@ -1,6 +1,6 @@
 import logging
-from mock import patch
-import mock
+from unittest.mock import patch
+import unittest.mock as mock
 from builtins import bytes
 from lxml import etree
 from pytest import raises
@@ -29,7 +29,7 @@ class TestSchema:
     def setup(self):
         test_xml = bytes(
             b"""<?xml version="1.0" encoding="utf-8"?>
-            <image schemaversion="1.4" name="bob">
+            <image schemaversion="7.4" name="bob">
                 <description type="system">
                     <author>John Doe</author>
                     <contact>john@example.com</contact>
@@ -49,7 +49,7 @@ class TestSchema:
         )
         test_xml_extension = bytes(
             b"""<?xml version="1.0" encoding="utf-8"?>
-            <image schemaversion="1.4" name="bob">
+            <image schemaversion="7.4" name="bob">
                 <description type="system">
                     <author>John Doe</author>
                     <contact>john@example.com</contact>
@@ -74,7 +74,7 @@ class TestSchema:
         )
         test_xml_extension_not_unique = bytes(
             b"""<?xml version="1.0" encoding="utf-8"?>
-            <image schemaversion="1.4" name="bob">
+            <image schemaversion="7.4" name="bob">
                 <description type="system">
                     <author>John Doe</author>
                     <contact>john@example.com</contact>
@@ -98,7 +98,7 @@ class TestSchema:
         )
         test_xml_extension_invalid = bytes(
             b"""<?xml version="1.0" encoding="utf-8"?>
-            <image schemaversion="1.4" name="bob">
+            <image schemaversion="7.4" name="bob">
                 <description type="system">
                     <author>John Doe</author>
                     <contact>john@example.com</contact>
@@ -172,11 +172,11 @@ class TestSchema:
         with raises(KiwiSchemaImportError):
             self.description_from_file.load()
 
-    @patch('importlib.import_module')
+    @patch('kiwi.xml_description.Defaults.get_schematron_module_name')
     def test_load_schema_from_xml_content_skipping_isoschematron(
-        self, mock_import_module
+        self, mock_get_schematron_module_name
     ):
-        mock_import_module.side_effect = Exception
+        mock_get_schematron_module_name.return_value = 'bogus'
         with self._caplog.at_level(logging.WARNING):
             self.description_from_data.load()
             assert 'schematron validation skipped:' in self._caplog.text
